# PyVRSim: Vehicle Routing Data Simulator in Python

[Pyvrsim](https://pypi.org/project/pyvrsim) is an open-source, user-friendly Python 3 library designed for simulating
data related to vehicle routing, capacitated vehicle routing, and drone routing problems. Utilizing the Google API,
Pyrosim extracts real distances and estimated times between locations, enhancing the accuracy and realism of
simulations.


<p align="center">
  <img src="docs/images/pyvrsim-logo.png" alt="My Logo" width="200" height="200">
</p>

# Installation

To install [Pyvrsim](https://pypi.org/project/pyvrsim), simply use pip to download and install the library from [PyPI](https://pypi.org/project/pyvrsim) (Python Package Index). The library is at PyPI at this page https://pypi.org/project/pyvrsim.

Install Pyrosim with the following command:

```python
pip install pyvrsim
```